# Setting Up a Microsoft Exchange Online Mailbox for Email Notifications
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/setting-up-microsoft-exchange-online-mailbox-for-email-notifications#overview)
  * [Prerequisites](https://help.sap.com/docs/leanix/ea/setting-up-microsoft-exchange-online-mailbox-for-email-notifications#prerequisites)
  * [Step 1: Grant Permissions](https://help.sap.com/docs/leanix/ea/setting-up-microsoft-exchange-online-mailbox-for-email-notifications#step-1:-grant-permissions)
  * [Step 2: Configure Security Settings](https://help.sap.com/docs/leanix/ea/setting-up-microsoft-exchange-online-mailbox-for-email-notifications#step-2:-configure-security-settings)
  * [Step 3: Activate Notifications](https://help.sap.com/docs/leanix/ea/setting-up-microsoft-exchange-online-mailbox-for-email-notifications#step-3:-activate-notifications)
  * [FAQs](https://help.sap.com/docs/leanix/ea/setting-up-microsoft-exchange-online-mailbox-for-email-notifications#faqs)


Set up a Microsoft Exchange Online mailbox to ensure enhanced security standards for email notification delivery.
